@@ -37,7 +37,7 @@ async fn answer(
 
 #[tokio::main]
 async fn main() {
-    teloxide::enable_logging!();
+    pretty_env_logger::init();
     log::info!("Starting simple_commands_bot...");
 
     let bot = Bot::from_env().auto_send();
