@@ -100,7 +100,6 @@ where
     ///
     /// [`shutdown`]: ShutdownToken::shutdown
     #[cfg(feature = "ctrlc_handler")]
-    #[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "ctrlc_handler")))]
     #[must_use]
     pub fn setup_ctrlc_handler(self) -> Self {
         let token = self.state.clone();
@@ -428,7 +427,7 @@ where
                     log::error!(
                         "Cannot parse an update.\nError: {:?}\n\
                             This is a bug in teloxide-core, please open an issue here: \
-                            https://github.com/teloxide/teloxide-core/issues.",
+                            https://github.com/teloxide/teloxide/issues.",
                         err,
                     );
                 }
