@@ -10,7 +10,7 @@
 //!
 //! # #[tokio::main]
 //! # async fn main() {
-//! teloxide::enable_logging!();
+//! pretty_env_logger::init();
 //! log::info!("Starting dices_bot...");
 //!
 //! let bot = Bot::from_env().auto_send();
@@ -53,7 +53,7 @@
 // ```console
 // $ RUSTFLAGS="--cfg dep_docsrs" RUSTDOCFLAGS="--cfg docsrs -Znormalize-docs" cargo +nightly doc --open --all-features
 // ```
-#![cfg_attr(all(docsrs, feature = "nightly"), feature(doc_cfg))]
+#![cfg_attr(all(docsrs, feature = "nightly"), feature(doc_cfg, doc_auto_cfg))]
 #![forbid(unsafe_code)]
 #![warn(rustdoc::broken_intra_doc_links)]
 #![allow(clippy::match_bool)]
@@ -61,12 +61,13 @@
 // https://github.com/rust-lang/rust-clippy/issues/7422
 #![allow(clippy::nonstandard_macro_braces)]
 
+#[cfg(feature = "ctrlc_handler")]
 pub use dispatching::repls::{
     commands_repl, commands_repl_with_listener, dialogues_repl, dialogues_repl_with_listener, repl,
     repl_with_listener,
 };
 
-#[cfg(feature = "dispatching2")]
+#[cfg(all(feature = "dispatching2", feature = "ctrlc_handler"))]
 pub use dispatching2::repls as repls2;
 
 mod logging;
@@ -74,12 +75,10 @@ mod logging;
 // Things from this module is also used for the dispatching2 module.
 pub mod dispatching;
 #[cfg(feature = "dispatching2")]
-#[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "dispatching2")))]
 pub mod dispatching2;
 pub mod error_handlers;
 pub mod prelude;
 #[cfg(feature = "dispatching2")]
-#[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "dispatching2")))]
 pub mod prelude2;
 pub mod utils;
 
@@ -87,13 +86,10 @@ pub mod utils;
 pub use teloxide_core::*;
 
 #[cfg(feature = "macros")]
-#[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "macros")))]
 pub use teloxide_macros as macros;
 
 #[cfg(feature = "dispatching2")]
-#[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "dispatching2")))]
 pub use dptree;
-#[cfg_attr(all(docsrs, feature = "nightly"), doc(cfg(feature = "macros")))]
 #[cfg(feature = "macros")]
 pub use teloxide_macros::teloxide;
 
